'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

const debounce = (fn, time) => {
  let timeout;

  return function (...args) {
    const context = this;
    if (timeout) {
      clearTimeout(timeout);
    }
    timeout = setTimeout(() => {
      fn.apply(context, args);
      timeout = null;
    }, time);
  };
};

const capitalizeFirstLetter = (string) => {
  if (!string || typeof string.charAt !== "function") {
    return string;
  }
  return string.charAt(0).toUpperCase() + string.slice(1);
};

const propsBinder = (methods, leafletElement, props, setOptions) => {
  for (const key in props) {
    const setMethodName = "set" + capitalizeFirstLetter(key);
    if (methods[setMethodName]) {
      vue.watch(
        () => props[key],
        (newVal, oldVal) => {
          methods[setMethodName](newVal, oldVal);
        }
      );
    } else if (setMethodName === "setOptions") {
      vue.watch(
        () => props[key],
        (newVal) => {
          setOptions(leafletElement, newVal);
        }
      );
    } else if (leafletElement[setMethodName]) {
      vue.watch(
        () => props[key],
        (newVal) => {
          leafletElement[setMethodName](newVal);
        }
      );
    }
  }
};

const remapEvents = (contextAttrs) => {
  const result = {};
  for (const attrName in contextAttrs) {
    if (attrName.startsWith("on") && !attrName.startsWith("onUpdate")) {
      const eventName = attrName.slice(2).toLocaleLowerCase();
      result[eventName] = contextAttrs[attrName];
    }
  }
  return result;
};

const resetWebpackIcon = (Icon) => {
  delete Icon.Default.prototype._getIconUrl;

  Icon.Default.mergeOptions({
    iconRetinaUrl: require("leaflet/dist/images/marker-icon-2x.png"),
    iconUrl: require("leaflet/dist/images/marker-icon.png"),
    shadowUrl: require("leaflet/dist/images/marker-shadow.png"),
  });
};

/**
 * Wraps a placeholder function and provides it with the given name.
 * The wrapper can later be updated with {@link updateLeafletWrapper}
 * to provide a different function.
 *
 * @param {String} methodName Key used to provide the wrapper function
 */
const provideLeafletWrapper = (methodName) => {
  const wrapped = vue.ref(() =>
    console.warn(`Method ${methodName} has been invoked without being replaced`)
  );
  const wrapper = (...args) => wrapped.value(...args);
  // eslint-disable-next-line vue/no-ref-as-operand
  wrapper.wrapped = wrapped;
  vue.provide(methodName, wrapper);

  return wrapper;
};

/**
 * Change the function that will be executed when an injected Leaflet wrapper
 * is invoked.
 *
 * @param {*} wrapper Provided wrapper whose wrapped function is to be updated
 * @param {function} leafletMethod New method to be wrapped by the wrapper
 */
const updateLeafletWrapper = (wrapper, leafletMethod) =>
  (wrapper.wrapped.value = leafletMethod);

const props = {
  pane: {
    type: String,
    default: "overlayPane",
  },
  attribution: {
    type: String,
    default: null,
  },
  name: {
    type: String,
    custom: true,
    default: undefined,
  },
  layerType: {
    type: String,
    custom: true,
    default: undefined,
  },
  visible: {
    type: Boolean,
    custom: true,
    default: true,
  },
};

const setup = (props, leafletRef, context) => {
  const addLayer = vue.inject("addLayer");
  const removeLayer = vue.inject("removeLayer");
  const options = {
    attribution: props.attribution,
    pane: props.pane,
  };

  const methods = {
    setAttribution(val, old) {
      const attributionControl = this.$parent.leafletObject.attributionControl;
      attributionControl.removeAttribution(old).addAttribution(val);
    },
    setName() {
      removeLayer(leafletRef.value);
      if (props.visible) {
        addLayer(leafletRef.value);
      }
    },
    setLayerType() {
      removeLayer(leafletRef.value);
      if (props.visible) {
        addLayer(leafletRef.value);
      }
    },
    setVisible(isVisible) {
      if (leafletRef.value) {
        if (isVisible) {
          addLayer(leafletRef.value);
        } else {
          removeLayer(leafletRef.value);
        }
      }
    },
    bindPopup({ leafletObject }) {
      leafletRef.value.bindPopup(leafletObject);
    },
    bindTooltip({ leafletObject }) {
      leafletRef.value.bindTooltip(leafletObject);
    },
    unbindTooltip() {
      const tooltip = leafletRef.value ? leafletRef.value.getTooltip() : null;
      if (tooltip) {
        tooltip.unbindTooltip();
      }
    },
    unbindPopup() {
      const popup = leafletRef.value ? leafletRef.value.getPopup() : null;
      if (popup) {
        popup.unbindPopup();
      }
    },
    updateVisibleProp(value) {
      /**
       * Triggers when the visible prop needs to be updated
       * @type {boolean}
       * @property {boolean} value - value of the visible property
       */
      context.emit("update:visible", value);
    },
  };

  vue.provide("bindPopup", methods.bindPopup);
  vue.provide("bindTooltip", methods.bindTooltip);
  vue.provide("unbindTooltip", methods.unbindTooltip);
  vue.provide("unbindPopup", methods.unbindPopup);

  vue.onUnmounted(() => {
    methods.unbindPopup();
    methods.unbindTooltip();
    removeLayer({ leafletObject: leafletRef.value });
  });

  return { options, methods };
};

const render = (ready, context) => () => {
  if (ready.value && context.slots.default) {
    return vue.h("div", { style: { display: "none" } }, context.slots.default());
  }
  return null;
};

const props$1 = {
  interactive: {
    type: Boolean,
    default: true,
  },
  bubblingMouseEvents: {
    type: Boolean,
    default: true,
  },
};

const setup$1 = (props) => {
  const options = {
    interactive: props.interactive,
    bubblingMouseEvents: props.bubblingMouseEvents,
  };

  const methods = {};

  return { options, methods };
};

const props$2 = {
  ...props,
  ...props$1,
  stroke: {
    type: Boolean,
    custom: true,
    default: true,
  },
  color: {
    type: String,
    custom: true,
    default: "#3388ff",
  },
  weight: {
    type: Number,
    custom: true,
    default: 3,
  },
  opacity: {
    type: Number,
    custom: true,
    default: 1.0,
  },
  lineCap: {
    type: String,
    custom: true,
    default: "round",
  },
  lineJoin: {
    type: String,
    custom: true,
    default: "round",
  },
  dashArray: {
    type: String,
    custom: true,
    default: null,
  },
  dashOffset: {
    type: String,
    custom: true,
    default: null,
  },
  fill: {
    type: Boolean,
    custom: true,
    default: false,
  },
  fillColor: {
    type: String,
    custom: true,
    default: "#3388ff",
  },
  fillOpacity: {
    type: Number,
    custom: true,
    default: 0.2,
  },
  fillRule: {
    type: String,
    custom: true,
    default: "evenodd",
  },
  className: {
    type: String,
    custom: true,
    default: null,
  },
};

const setup$2 = (props, leafletRef, context) => {
  const { options: layerOptions, methods: layerMethods } = setup(
    props,
    leafletRef,
    context
  );
  const {
    options: interactiveLayerOptions,
    methods: interactiveLayerMethods,
  } = setup$1(props);

  const removeLayer = vue.inject("removeLayer");

  const options = {
    ...layerOptions,
    ...interactiveLayerOptions,
    stroke: props.stroke,
    color: props.color,
    weight: props.weight,
    opacity: props.opacity,
    lineCap: props.lineCap,
    lineJoin: props.lineJoin,
    dashArray: props.dashArray,
    dashOffset: props.dashOffset,
    fill: props.fill,
    fillColor: props.fillColor,
    fillOpacity: props.fillOpacity,
    fillRule: props.fillRule,
    className: props.className,
  };
  const methods = {
    ...layerMethods,
    ...interactiveLayerMethods,
    setStroke(stroke) {
      leafletRef.value.setStyle({ stroke });
    },
    setColor(color) {
      leafletRef.value.setStyle({ color });
    },
    setWeight(weight) {
      leafletRef.value.setStyle({ weight });
    },
    setOpacity(opacity) {
      leafletRef.value.setStyle({ opacity });
    },
    setLineCap(lineCap) {
      leafletRef.value.setStyle({ lineCap });
    },
    setLineJoin(lineJoin) {
      leafletRef.value.setStyle({ lineJoin });
    },
    setDashArray(dashArray) {
      leafletRef.value.setStyle({ dashArray });
    },
    setDashOffset(dashOffset) {
      leafletRef.value.setStyle({ dashOffset });
    },
    setFill(fill) {
      leafletRef.value.setStyle({ fill });
    },
    setFillColor(fillColor) {
      leafletRef.value.setStyle({ fillColor });
    },
    setFillOpacity(fillOpacity) {
      leafletRef.value.setStyle({ fillOpacity });
    },
    setFillRule(fillRule) {
      leafletRef.value.setStyle({ fillRule });
    },
    setClassName(className) {
      leafletRef.value.setStyle({ className });
    },
  };

  vue.onBeforeUnmount(() => {
    removeLayer();
  });

  return { options, methods };
};

const props$3 = {
  ...props$2,
  latLng: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  /**
   * Radius of the marker in pixels.
   */
  radius: {
    type: Number,
    default: null,
  },
};

const setup$3 = (props, leafletRef, context) => {
  const { options: pathOptions, methods: pathMethods } = setup$2(
    props,
    leafletRef,
    context
  );
  const options = {
    ...pathOptions,
    ...props,
  };
  const methods = {
    ...pathMethods,
    setRadius(radius) {
      leafletRef.value.setRadius(radius);
    },
    setLatLng(latLng) {
      leafletRef.value.setLatLng(latLng);
    },
  };

  return { options, methods };
};

const props$4 = {
  ...props$3,
  /**
   * Radius of the circle in meters.
   */
  radius: {
    type: Number,
    default: null,
  },
};

const setup$4 = (props, leafletRef, context) => {
  const {
    options: circleMarkerOptions,
    methods: circleMarkerMethods,
  } = setup$3(props, leafletRef, context);
  const options = {
    ...circleMarkerOptions,
    ...props,
  };
  const methods = {
    ...circleMarkerMethods,
  };

  return { options, methods };
};

/**
 * Circle component, lets you add and personalize circles on the map
 */
var script = {
  name: "LCircle",
  props: props$4,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$4(props, leafletRef, context);

    vue.onMounted(async () => {
      const { circle, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = circle(props.latLng, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);

      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });
    return render(ready, context);
  },
};

const render$1 = () => {};


script.render = render$1;
script.__file = "src/components/LCircle.vue";

/**
 * Circle Marker component, lets you add and personalize circle markers on the map
 */
var script$1 = {
  name: "LCircleMarker",
  props: props$3,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$3(props, leafletRef, context);

    vue.onMounted(async () => {
      const { circleMarker, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = circleMarker(props.latLng, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);

      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });
    return render(ready, context);
  },
};

const render$2 = () => {};


script$1.render = render$2;
script$1.__file = "src/components/LCircleMarker.vue";

const props$5 = {
  position: {
    type: String,
    default: "topright",
  },
};

const setup$5 = (props, leafletRef) => {
  const options = {
    position: props.position,
  };

  const methods = {
    setPosition(position) {
      if (leafletRef.value) {
        leafletRef.value.setPosition(position);
      }
    },
  };

  vue.onUnmounted(() => {
    if (leafletRef.value) {
      leafletRef.value.remove();
    }
  });

  return { options, methods };
};

const render$3 = (context, root) => () => {
  if (context.slots.default) {
    return vue.h("div", { ref: root }, context.slots.default());
  }
  return null;
};

const props$6 = {
  ...props$5,
  prefix: {
    type: String,
    default: "Vue-Leaflet",
    custom: true,
  },
};

const setup$6 = (props, leafletRef) => {
  const { options: controlOptions, methods: controlMethods } = setup$5(
    props,
    leafletRef
  );
  const options = {
    ...controlOptions,
    prefix: props.prefix,
  };

  const methods = {
    ...controlMethods,
    setPrefix(prefix) {
      leafletRef.value.setPrefix(prefix);
    },
  };

  return { options, methods };
};

var script$2 = {
  name: "LControlAttribution",
  props: props$6,
  setup(props) {
    const leafletRef = vue.ref({});

    const registerControl = vue.inject("registerControl");
    const { options, methods } = setup$6(props, leafletRef);
    vue.onMounted(async () => {
      const { control, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = control.attribution(options);
      propsBinder(methods, leafletRef.value, props, setOptions);
      registerControl({ leafletObject: leafletRef.value });
    });
  },
  render() {
    return null;
  },
};

const render$4 = () => {};


script$2.render = render$4;
script$2.__file = "src/components/LControlAttribution.vue";

const props$7 = {
  ...props$5,
  collapsed: {
    type: Boolean,
    default: true,
  },
  autoZIndex: {
    type: Boolean,
    default: true,
  },
  hideSingleBase: {
    type: Boolean,
    default: false,
  },
  sortLayers: {
    type: Boolean,
    default: false,
  },
  sortFunction: {
    type: Function,
    default: undefined,
  },
};

const setup$7 = (props, leafletRef) => {
  const { options: controlOptions } = setup$5(props, leafletRef);
  const options = {
    ...controlOptions,
    collapsed: props.collapsed,
    autoZIndex: props.autoZIndex,
    hideSingleBase: props.hideSingleBase,
    sortLayers: props.sortLayers,
    sortFunction: props.sortFunction,
  };

  const methods = {
    addLayer(layer) {
      if (layer.layerType === "base") {
        leafletRef.value.addBaseLayer(layer.leafletObject, layer.name);
      } else if (layer.layerType === "overlay") {
        leafletRef.value.addOverlay(layer.leafletObject, layer.name);
      }
    },
    removeLayer(layer) {
      leafletRef.value.removeLayer(layer.leafletObject);
    },
  };
  return { options, methods };
};

var script$3 = {
  name: "LControlLayers",
  props: props$7,
  setup(props) {
    const leafletRef = vue.ref({});

    const registerLayerControl = vue.inject("registerLayerControl");
    const { options, methods } = setup$7(props, leafletRef);
    vue.onMounted(async () => {
      const { control, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = control.layers(null, null, options);
      propsBinder(methods, leafletRef.value, props, setOptions);

      registerLayerControl({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
    });
  },
  render() {
    return null;
  },
};

const render$5 = () => {};


script$3.render = render$5;
script$3.__file = "src/components/LControlLayers.vue";

const props$8 = {
  ...props$5,
  maxWidth: {
    type: Number,
    default: 100,
  },
  metric: {
    type: Boolean,
    default: true,
  },
  imperial: {
    type: Boolean,
    default: true,
  },
  updateWhenIdle: {
    type: Boolean,
    default: false,
  },
};

const setup$8 = (props, leafletRef) => {
  const { options: controlOptions, methods: controlMethods } = setup$5(
    props,
    leafletRef
  );
  const options = {
    ...controlOptions,
    maxWidth: props.maxWidth,
    metric: props.metric,
    imperial: props.imperial,
    updateWhenIdle: props.updateWhenIdle,
  };

  return { options, methods: controlMethods };
};

var script$4 = {
  name: "LControlScale",
  props: props$8,
  setup(props) {
    const leafletRef = vue.ref({});

    const registerControl = vue.inject("registerControl");
    const { options, methods } = setup$8(props, leafletRef);
    vue.onMounted(async () => {
      const { control, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = control.scale(options);
      propsBinder(methods, leafletRef.value, props, setOptions);
      registerControl({ leafletObject: leafletRef.value });
    });
  },
  render() {
    return null;
  },
};

const render$6 = () => {};


script$4.render = render$6;
script$4.__file = "src/components/LControlScale.vue";

const props$9 = {
  ...props$5,
  zoomInText: {
    type: String,
    default: "+",
  },
  zoomInTitle: {
    type: String,
    default: "Zoom in",
  },
  zoomOutText: {
    type: String,
    default: "-",
  },
  zoomOutTitle: {
    type: String,
    default: "Zoom out",
  },
};

const setup$9 = (props, leafletRef) => {
  const { options: controlOptions, methods: controlMethods } = setup$5(
    props,
    leafletRef
  );
  const options = {
    ...controlOptions,
    zoomInText: props.zoomInText,
    zoomInTitle: props.zoomInTitle,
    zoomOutText: props.zoomOutText,
    zoomOutTitle: props.zoomOutTitle,
  };

  return { options, methods: controlMethods };
};

var script$5 = {
  name: "LControlZoom",
  props: props$9,
  setup(props) {
    const leafletRef = vue.ref({});

    const registerControl = vue.inject("registerControl");
    const { options, methods } = setup$9(props, leafletRef);
    vue.onMounted(async () => {
      const { control, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = control.zoom(options);
      propsBinder(methods, leafletRef.value, props, setOptions);
      registerControl({ leafletObject: leafletRef.value });
    });
  },
  render() {
    return null;
  },
};

const render$7 = () => {};


script$5.render = render$7;
script$5.__file = "src/components/LControlZoom.vue";

var script$6 = {
  name: "LControl",
  props: {
    ...props$5,
    disableClickPropagation: {
      type: Boolean,
      custom: true,
      default: true,
    },
    disableScrollPropagation: {
      type: Boolean,
      custom: true,
      default: false,
    },
  },
  setup(props, context) {
    const leafletRef = vue.ref({});
    const root = vue.ref(null);

    const registerControl = vue.inject("registerControl");
    const { options, methods } = setup$5(props, leafletRef);
    vue.onMounted(async () => {
      const { Control, setOptions, DomEvent } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      const LControl = Control.extend({
        onAdd() {
          return root.value;
        },
      });

      leafletRef.value = new LControl(options);
      propsBinder(methods, leafletRef.value, props, setOptions);
      registerControl({ leafletObject: leafletRef.value });

      if (props.disableClickPropagation) {
        DomEvent.disableClickPropagation(root.value);
      }
      if (props.disableScrollPropagation) {
        DomEvent.disableScrollPropagation(root.value);
      }
    });

    return render$3(context, root);
  },
};

const render$8 = () => {};


script$6.render = render$8;
script$6.__file = "src/components/LControl.vue";

var script$7 = {
  props: {
    /**
     * The center of the map, supports .sync modifier
     */
    center: {
      type: [Object, Array],
      default: () => [0, 0],
    },
    /**
     * The bounds of the map, supports .sync modifier
     */
    bounds: {
      type: [Array, Object],
      default: undefined,
    },
    /**
     * The max bounds of the map
     */
    maxBounds: {
      type: [Array, Object],
      default: undefined,
    },
    /**
     * The zoom of the map, supports .sync modifier
     */
    zoom: {
      type: Number,
      default: 0,
    },
    /**
     * The minZoom of the map
     */
    minZoom: {
      type: Number,
      default: undefined,
    },
    /**
     * The maxZoom of the map
     */
    maxZoom: {
      type: Number,
      default: undefined,
    },
    /**
     * The paddingBottomRight of the map
     */
    paddingBottomRight: {
      type: Array,
      default: undefined,
    },
    /**
     * The paddingTopLeft of the map
     */
    paddingTopLeft: {
      type: Array,
      default: undefined,
    },
    /**
     * The padding of the map
     */
    padding: {
      type: Array,
      default: undefined,
    },
    /**
     * The worldCopyJump option for the map
     */
    worldCopyJump: {
      type: Boolean,
      default: false,
    },
    /**
     * The crs option for the map
     * @values CRS.EPSG3857
     */
    crs: {
      type: Object,
    },
    maxBoundsViscosity: {
      type: Number,
      default: undefined,
    },
    inertia: {
      type: Boolean,
      default: undefined,
    },
    inertiaDeceleration: {
      type: Number,
      default: undefined,
    },
    inertiaMaxSpeed: {
      type: Number,
      default: undefined,
    },
    easeLinearity: {
      type: Number,
      default: undefined,
    },
    zoomAnimation: {
      type: Boolean,
      default: undefined,
    },
    zoomAnimationThreshold: {
      type: Number,
      default: undefined,
    },
    fadeAnimation: {
      type: Boolean,
      default: undefined,
    },
    markerZoomAnimation: {
      type: Boolean,
      default: undefined,
    },
    noBlockingAnimations: {
      type: Boolean,
      default: false,
    },
  },
  setup(props, context) {
    const root = vue.ref(null);
    const blueprint = vue.reactive({
      ready: false,
      leafletRef: {},
      layersToAdd: [],
      layersInControl: [],
    });

    const options = {
      minZoom: props.minZoom,
      maxZoom: props.maxZoom,
      maxBounds: props.maxBounds,
      maxBoundsViscosity: props.maxBoundsViscosity,
      worldCopyJump: props.worldCopyJump,
      crs: props.crs,
      center: props.center,
      zoom: props.zoom,
      inertia: props.inertia,
      inertiaDeceleration: props.inertiaDeceleration,
      inertiaMaxSpeed: props.inertiaMaxSpeed,
      easeLinearity: props.easeLinearity,
      zoomAnimation: props.zoomAnimation,
      zoomAnimationThreshold: props.zoomAnimationThreshold,
      fadeAnimation: props.fadeAnimation,
      markerZoomAnimation: props.markerZoomAnimation,
    };

    const addLayer = provideLeafletWrapper("addLayer");
    const removeLayer = provideLeafletWrapper("removeLayer");
    const registerControl = provideLeafletWrapper("registerControl");
    const registerLayerControl = provideLeafletWrapper("registerLayerControl");

    const eventHandlers = {
      moveEndHandler() {
        /**
         * Triggers when zoom is updated
         * @type {number,string}
         */
        context.emit("update:zoom", blueprint.leafletRef.getZoom());
        /**
         * Triggers when center is updated
         * @type {object,array}
         */
        context.emit("update:center", blueprint.leafletRef.getCenter());

        /**
         * Triggers when bounds are updated
         * @type {object}
         */
        context.emit("update:bounds", blueprint.leafletRef.getBounds());
      },
      overlayAddHandler(e) {
        const layer = blueprint.layersInControl.find((l) => l.name === e.name);
        if (layer) {
          layer.updateVisibleProp(true);
        }
      },
      overlayRemoveHandler(e) {
        const layer = blueprint.layersInControl.find((l) => l.name === e.name);
        if (layer) {
          layer.updateVisibleProp(false);
        }
      },
    };

    vue.onMounted(async () => {
      const {
        map,
        CRS,
        Icon,
        latLngBounds,
        latLng,
        DomEvent,
        setOptions,
      } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('leaflet/dist/leaflet-src.esm')); });
      resetWebpackIcon(Icon);
      options.crs = options.crs || CRS.EPSG3857;

      const methods = {
        addLayer(layer) {
          if (layer.layerType !== undefined) {
            if (blueprint.layerControl === undefined) {
              blueprint.layersToAdd.push(layer);
            } else {
              const exist = blueprint.layersInControl.find(
                (l) =>
                  l.leafletObject._leaflet_id ===
                  layer.leafletObject._leaflet_id
              );
              if (!exist) {
                blueprint.layerControl.addLayer(layer);
                blueprint.layersInControl.push(layer);
              }
            }
          }
          if (layer.visible !== false) {
            blueprint.leafletRef.addLayer(layer.leafletObject);
          }
        },
        removeLayer(layer) {
          if (layer.layerType !== undefined) {
            if (blueprint.layerControl === undefined) {
              blueprint.layersToAdd = blueprint.layersToAdd.filter(
                (l) => l.name !== layer.name
              );
            } else {
              blueprint.layerControl.removeLayer(layer.leafletObject);
              blueprint.layersInControl = blueprint.layersInControl.filter(
                (l) =>
                  l.leafletObject._leaflet_id !==
                  layer.leafletObject._leaflet_id
              );
            }
          }
          blueprint.leafletRef.removeLayer(layer.leafletObject);
        },

        registerLayerControl(lControlLayer) {
          blueprint.layerControl = lControlLayer;
          blueprint.layersToAdd.forEach((layer) => {
            blueprint.layerControl.addLayer(layer);
          });
          blueprint.layersToAdd = [];

          registerControl(lControlLayer);
        },

        registerControl(lControl) {
          blueprint.leafletRef.addControl(lControl.leafletObject);
        },

        setZoom(newVal) {
          const zoom = blueprint.leafletRef.getZoom();
          if (newVal !== zoom) {
            blueprint.leafletRef.setZoom(newVal, {
              animate: props.noBlockingAnimations ? false : null,
            });
          }
        },

        setPaddingBottomRight(newVal) {
          blueprint.paddingBottomRight = newVal;
        },
        setPaddingTopLeft(newVal) {
          blueprint.paddingTopLeft = newVal;
        },
        setPadding(newVal) {
          blueprint.padding = newVal;
        },
        setCrs(newVal) {
          const prevBounds = blueprint.leafletRef.getBounds();
          blueprint.leafletRef.options.crs = newVal;
          blueprint.leafletRef.fitBounds(prevBounds, {
            animate: false,
            padding: [0, 0],
          });
        },
        fitBounds(bounds) {
          blueprint.leafletRef.fitBounds(bounds, {
            animate: this.noBlockingAnimations ? false : null,
          });
        },
        setBounds(newVal) {
          if (!newVal) {
            return;
          }
          const newBounds = latLngBounds(newVal);
          if (!newBounds.isValid()) {
            return;
          }
          const oldBounds =
            blueprint.lastSetBounds || blueprint.leafletRef.getBounds();
          const boundsChanged = !oldBounds.equals(newBounds, 0); // set maxMargin to 0 - check exact equals
          if (boundsChanged) {
            blueprint.lastSetBounds = newBounds;
            blueprint.leafletRef.fitBounds(newBounds, this.fitBoundsOptions);
          }
        },

        setCenter(newVal) {
          if (newVal == null) {
            return;
          }
          const newCenter = latLng(newVal);
          const oldCenter =
            blueprint.lastSetCenter || blueprint.leafletRef.getCenter();
          if (
            oldCenter.lat !== newCenter.lat ||
            oldCenter.lng !== newCenter.lng
          ) {
            blueprint.lastSetCenter = newCenter;
            blueprint.leafletRef.panTo(newCenter, {
              animate: this.noBlockingAnimations ? false : null,
            });
          }
        },
      };

      updateLeafletWrapper(addLayer, methods.addLayer);
      updateLeafletWrapper(removeLayer, methods.removeLayer);
      updateLeafletWrapper(registerControl, methods.registerControl);
      updateLeafletWrapper(registerLayerControl, methods.registerLayerControl);

      blueprint.leafletRef = map(root.value, options);

      propsBinder(methods, blueprint.leafletRef, props, setOptions);
      const listeners = remapEvents(context.attrs);

      blueprint.leafletRef.on(
        "moveend",
        debounce(eventHandlers.moveEndHandler, 100)
      );
      blueprint.leafletRef.on("overlayadd", eventHandlers.overlayAddHandler);
      blueprint.leafletRef.on(
        "overlayremove",
        eventHandlers.overlayRemoveHandler
      );
      DomEvent.on(blueprint.leafletRef, listeners);
      blueprint.ready = true;
      vue.nextTick(() => context.emit("ready"));
    });

    vue.onBeforeUnmount(() => {
      if (blueprint.leafletRef) {
        blueprint.leafletRef.remove();
      }
    });

    const leafletObject = vue.computed(() => blueprint.leafletRef);
    const ready = vue.computed(() => blueprint.ready);
    return { root, ready, leafletObject };
  },
};

const _hoisted_1 = {
  style: {"width":"100%","height":"100%"},
  ref: "root"
};

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock("div", _hoisted_1, [
    ($setup.ready)
      ? vue.renderSlot(_ctx.$slots, "default", { key: 0 })
      : vue.createCommentVNode("v-if", true)
  ], 512 /* NEED_PATCH */))
}

script$7.render = render$9;
script$7.__file = "src/components/LMap.vue";

const props$a = {
  ...props,
  pane: {
    type: String,
    default: "markerPane",
  },
  draggable: {
    type: Boolean,
    custom: true,
    default: false,
  },
  latLng: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  icon: {
    type: [Object],
    custom: false,
  },
  zIndexOffset: {
    type: Number,
    custom: false,
    default: null,
  },
};

const setup$a = (props, leafletRef, context) => {
  const { options: layerOptions, methods: layerMethods } = setup(
    props,
    leafletRef,
    context
  );
  const options = {
    ...layerOptions,
    ...props,
  };
  const latLng = vue.inject("latLng");

  const methods = {
    ...layerMethods,
    setDraggable(value) {
      if (leafletRef.value.dragging) {
        value
          ? leafletRef.value.dragging.enable()
          : leafletRef.value.dragging.disable();
      }
    },
    latLngSync(event) {
      context.emit("update:latLng", event.latlng);
      context.emit("update:lat-lng", event.latlng);
    },
    setLatLng(newVal) {
      if (newVal == null) {
        return;
      }

      if (leafletRef.value) {
        const oldLatLng = leafletRef.value.getLatLng();
        const newLatLng = latLng(newVal);
        if (
          newLatLng.lat !== oldLatLng.lat ||
          newLatLng.lng !== oldLatLng.lng
        ) {
          leafletRef.value.setLatLng(newLatLng);
        }
      }
    },
  };
  return { options, methods };
};

/**
 * Marker component, lets you add and personalize markers on the map
 */
var script$8 = {
  name: "LMarker",
  props: props$a,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const latLng = provideLeafletWrapper("latLng");
    vue.provide("canSetParentHtml", () => !!leafletRef.value.getElement());
    vue.provide(
      "setParentHtml",
      (html) => (leafletRef.value.getElement().innerHTML = html)
    );
    vue.provide(
      "setIcon",
      (newIcon) => leafletRef.value.setIcon && leafletRef.value.setIcon(newIcon)
    );
    const { options, methods } = setup$a(props, leafletRef, context);

    vue.onMounted(async () => {
      const {
        marker,
        DomEvent,
        latLng: leafletLatLng,
        setOptions,
      } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('leaflet/dist/leaflet-src.esm')); });
      updateLeafletWrapper(latLng, leafletLatLng);

      leafletRef.value = marker(props.latLng, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      leafletRef.value.on("move", debounce(methods.latLngSync, 100));
      propsBinder(methods, leafletRef.value, props, setOptions);
      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });

    return render(ready, context);
  },
};

const render$a = () => {};


script$8.render = render$a;
script$8.__file = "src/components/LMarker.vue";

const props$b = {
  ...props,
  pane: {
    type: String,
    default: "tilePane",
  },
  opacity: {
    type: Number,
    custom: false,
    default: 1.0,
  },
  zIndex: {
    type: Number,
    default: 1,
  },
  tileSize: {
    type: Number,
    default: 256,
  },
  noWrap: {
    type: Boolean,
    default: false,
  },
};

const setup$b = (props, leafletRef) => {
  const { options: layerOptions, methods: layerMethods } = setup(
    props,
    leafletRef
  );
  const options = {
    ...layerOptions,
    pane: props.pane,
    opacity: props.opacity,
    zIndex: props.zIndex,
    tileSize: props.tileSize,
    noWrap: props.noWrap,
  };
  return { options, methods: { ...layerMethods } };
};

const props$c = {
  ...props$b,
  tms: {
    type: Boolean,
    default: false,
  },
  subdomains: {
    type: String,
    default: "abc",
  },
  detectRetina: {
    type: Boolean,
    default: false,
  },
  url: {
    type: String,
    default: null,
  },
};

const setup$c = (props, leafletRef) => {
  const {
    options: gridLayerOptions,
    methods: gridLayerMethods,
  } = setup$b(props, leafletRef);
  const options = {
    ...gridLayerOptions,
    tms: props.tms,
    subdomains: props.subdomains,
    detectRetina: props.detectRetina,
  };
  return {
    options,
    methods: {
      ...gridLayerMethods,
    },
  };
};

var script$9 = {
  props: props$c,
  setup(props, context) {
    const leafletRef = vue.ref({});

    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$c(props, leafletRef);

    vue.onMounted(async () => {
      const { tileLayer, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });
      leafletRef.value = tileLayer(props.url, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);
      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
    });
  },
  render() {
    return null;
  },
};

const render$b = () => {};


script$9.render = render$b;
script$9.__file = "src/components/LTileLayer.vue";

const props$d = {
  iconUrl: {
    type: String,
    custom: true,
    default: null,
  },
  iconRetinaUrl: {
    type: String,
    custom: true,
    default: null,
  },
  iconSize: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  iconAnchor: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  popupAnchor: {
    type: [Object, Array],
    custom: true,
    default: () => [0, 0],
  },
  tooltipAnchor: {
    type: [Object, Array],
    custom: true,
    default: () => [0, 0],
  },
  shadowUrl: {
    type: String,
    custom: true,
    default: null,
  },
  shadowRetinaUrl: {
    type: String,
    custom: true,
    default: null,
  },
  shadowSize: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  shadowAnchor: {
    type: [Object, Array],
    custom: true,
    default: null,
  },
  bgPos: {
    type: [Object, Array],
    custom: true,
    default: () => [0, 0],
  },
  className: {
    type: String,
    custom: true,
    default: "",
  },
  options: {
    type: Object,
    custom: true,
    default: () => ({}),
  },
};

/**
 * Icon component, lets you add and custom icons to the map
 */
var script$a = {
  name: "LIcon",
  props: props$d,
  setup(props, context) {
    const root = vue.ref(null);

    const canSetParentHtml = vue.inject("canSetParentHtml");
    const setParentHtml = vue.inject("setParentHtml");
    const setIcon = vue.inject("setIcon");

    let onDomEvent;
    let offDomEvent;
    let divIcon;
    let icon;
    let iconObject = undefined;

    const createIcon = (el, recreationNeeded, htmlSwapNeeded) => {
      const elHtml = el && el.innerHTML;
      if (!recreationNeeded) {
        if (htmlSwapNeeded && iconObject && canSetParentHtml()) {
          setParentHtml(elHtml);
        }
        return;
      }

      const listeners = remapEvents(context.attrs);
      if (iconObject) {
        offDomEvent(iconObject, listeners);
      }

      const options = {
        ...props,
      };

      if (elHtml) {
        options.html = elHtml;
      }

      iconObject = options.html ? divIcon(options) : icon(options);
      onDomEvent(iconObject, listeners);
      setIcon(iconObject);
    };

    const scheduleCreateIcon = () => {
      vue.nextTick(() => createIcon(root.value, true, false));
    };

    const scheduleHtmlSwap = () => {
      vue.nextTick(() => createIcon(root.value, false, true));
    };

    const methods = {
      setIconUrl: scheduleCreateIcon,
      setIconRetinaUrl: scheduleCreateIcon,
      setIconSize: scheduleCreateIcon,
      setIconAnchor: scheduleCreateIcon,
      setPopupAnchor: scheduleCreateIcon,
      setTooltipAnchor: scheduleCreateIcon,
      setShadowUrl: scheduleCreateIcon,
      setShadowRetinaUrl: scheduleCreateIcon,
      setShadowAnchor: scheduleCreateIcon,
      setBgPos: scheduleCreateIcon,
      setClassName: scheduleCreateIcon,
      setHtml: scheduleCreateIcon,
    };

    vue.onMounted(async () => {
      const { DomEvent, divIcon: lDivIcon, icon: lIcon } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      onDomEvent = DomEvent.on;
      offDomEvent = DomEvent.off;
      divIcon = lDivIcon;
      icon = lIcon;

      propsBinder(methods, {}, props);

      const observer = new MutationObserver(scheduleHtmlSwap);
      observer.observe(root.value, {
        attributes: true,
        childList: true,
        characterData: true,
        subtree: true,
      });
      scheduleCreateIcon();
    });

    return () => {
      const content = context.slots.default
        ? context.slots.default()
        : undefined;

      return vue.h("div", { ref: root }, content);
    };
  },
};

const render$c = () => {};


script$a.render = render$c;
script$a.__file = "src/components/LIcon.vue";

const props$e = {
  ...props$2,
  latLngs: {
    type: Array,
    default: () => [],
  },
  smoothFactor: {
    type: Number,
    custom: true,
    default: 1.0,
  },
  noClip: {
    type: Boolean,
    custom: true,
    default: false,
  },
};

const setup$d = (props, leafletRef, context) => {
  const { options: pathOptions, methods: pathMethods } = setup$2(
    props,
    leafletRef,
    context
  );
  const options = {
    ...pathOptions,
    ...props,
  };

  const methods = {
    ...pathMethods,
    setSmoothFactor(smoothFactor) {
      leafletRef.value.setStyle({ smoothFactor });
    },
    setNoClip(noClip) {
      leafletRef.value.setStyle({ noClip });
    },
    addLatLng(latLng) {
      leafletRef.value.addLatLng(latLng);
    },
  };
  return { options, methods };
};

/**
 * Polyline component, lets you add and personalize polylines on the map
 */
var script$b = {
  name: "LPolyline",
  props: props$e,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$d(props, leafletRef, context);

    vue.onMounted(async () => {
      const { polyline, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = polyline(props.latLngs, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);

      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });
    return render(ready, context);
  },
};

const render$d = () => {};


script$b.render = render$d;
script$b.__file = "src/components/LPolyline.vue";

const props$f = {
  content: {
    type: String,
    default: null,
  },
};

const setup$e = (props, leafletRef) => {
  const options = {};
  const methods = {
    setContent(newVal) {
      if (leafletRef.value && newVal !== null && newVal !== undefined) {
        leafletRef.value.setContent(newVal);
      }
    },
  };
  return { options, methods };
};

const render$e = (root, context) => () => {
  if (context.slots.default) {
    return vue.h("div", { ref: root }, context.slots.default());
  }
  return null;
};

const props$g = {
  ...props$f,
};

const setup$f = (props, leafletRef) => {
  const { options, methods } = setup$e(props, leafletRef);
  const unbindTooltip = vue.inject("unbindTooltip");

  vue.onBeforeUnmount(() => {
    unbindTooltip();
  });

  return { options, methods };
};

/**
 * Display a tooltip on the map
 */
var script$c = {
  name: "LTooltip",
  props: props$g,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const root = vue.ref(null);

    const bindTooltip = vue.inject("bindTooltip");
    const { options, methods } = setup$f(props, leafletRef);

    vue.onMounted(async () => {
      const { tooltip, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = tooltip(options);

      propsBinder(methods, leafletRef.value, props, setOptions);
      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);
      leafletRef.value.setContent(props.content || root.value);
      bindTooltip({ leafletObject: leafletRef.value });
    });
    return render$e(root, context);
  },
};

const render$f = () => {};


script$c.render = render$f;
script$c.__file = "src/components/LTooltip.vue";

const props$h = {
  ...props$f,
  latLng: {
    type: [Object, Array],
    default: () => [],
  },
};

const setup$g = (props, leafletRef) => {
  const { options, methods } = setup$e(props, leafletRef);
  const unbindPopup = vue.inject("unbindPopup");

  vue.onBeforeUnmount(() => {
    unbindPopup();
  });

  return { options, methods };
};

/**
 * Display a popup on the map
 */
var script$d = {
  name: "LPopup",
  props: props$h,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const root = vue.ref(null);

    const bindPopup = vue.inject("bindPopup");
    const { options, methods } = setup$g(props, leafletRef);

    vue.onMounted(async () => {
      const { popup, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = popup(options);

      if (props.latLng !== undefined) {
        leafletRef.value.setLatLng(props.latLng);
      }

      propsBinder(methods, leafletRef.value, props, setOptions);
      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);
      leafletRef.value.setContent(props.content || root.value);
      bindPopup({ leafletObject: leafletRef.value });
    });
    return render$e(root, context);
  },
};

const render$g = () => {};


script$d.render = render$g;
script$d.__file = "src/components/LPopup.vue";

const props$i = {
  ...props$e,
};

const setup$h = (props, leafletRef, context) => {
  const { options: polylineOptions, methods: polylineMethods } = setup$d(
    props,
    leafletRef,
    context
  );
  const options = {
    ...polylineOptions,
    ...props,
  };

  const methods = {
    ...polylineMethods,
    toGeoJSON(precision) {
      return leafletRef.value.toGeoJSON(precision);
    },
  };

  return { options, methods };
};

/**
 * Polygon component, lets you add and customize polygon regions on the map
 */
var script$e = {
  name: "LPolygon",
  props: props$i,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);
    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$h(props, leafletRef, context);

    vue.onMounted(async () => {
      const { polygon, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = polygon(props.latLngs, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);

      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });

    return render(ready, context);
  },
};

const render$h = () => {};


script$e.render = render$h;
script$e.__file = "src/components/LPolygon.vue";

const props$j = {
  ...props$i,
  bounds: {
    type: Array,
    default: undefined,
  },
};

const setup$i = (props, leafletRef, context) => {
  const { options: polygonOptions, methods: polygonMethods } = setup$h(
    props,
    leafletRef,
    context
  );
  const options = {
    ...polygonOptions,
    ...props,
  };

  const methods = {
    ...polygonMethods,
    setBounds(latLngBounds) {
      leafletRef.value.setBounds(latLngBounds);
    },
    setLatLngs(latLngs) {
      // Calling setLatLngs on a Leaflet rectangle will convert it
      // to a polygon. So instead, we call setBounds here to ensure
      // that the rectangle remains a rectangle, defined by the
      // bounds of the points in the latLngs array.
      leafletRef.value.setBounds(latLngs);
    },
  };

  return { options, methods };
};

/**
 * Rectangle component, lets you add and customize rectangular regions on the map
 */
var script$f = {
  name: "LRectangle",
  props: props$j,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);
    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$i(props, leafletRef, context);

    vue.onMounted(async () => {
      const { rectangle, latLngBounds, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      const bounds =
        props.bounds && props.bounds.length
          ? latLngBounds(props.bounds)
          : latLngBounds(props.latLngs);
      leafletRef.value = rectangle(bounds, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);

      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });

    return render(ready, context);
  },
};

const render$i = () => {};


script$f.render = render$i;
script$f.__file = "src/components/LRectangle.vue";

const props$k = {
  ...props$c,
  baseUrl: {
    type: String,
    default: null,
    required: true,
  },
  layers: {
    type: String,
    default: "",
  },
  styles: {
    type: String,
    default: "",
  },
  format: {
    type: String,
    default: "image/jpeg",
  },
  transparent: {
    type: Boolean,
    custom: false,
  },
  version: {
    type: String,
    default: "1.1.1",
  },
  crs: {
    default: null,
  },
  upperCase: {
    type: Boolean,
    default: false,
  },
};

const setup$j = (props, leafletRef) => {
  const {
    options: tileLayerOptions,
    methods: tileLayerMethods,
  } = setup$c(props, leafletRef);
  const options = {
    ...tileLayerOptions,
    layers: props.layers,
    styles: props.styles,
    format: props.format,
    transparent: props.transparent,
    version: props.version,
    crs: props.crs,
    upperCase: props.upperCase,
  };
  return {
    options,
    methods: {
      ...tileLayerMethods,
    },
  };
};

var script$g = {
  props: props$k,
  setup(props, context) {
    const leafletRef = vue.ref({});

    const addLayer = vue.inject("addLayer");

    const { options, methods } = setup$j(props, leafletRef);

    vue.onMounted(async () => {
      const { tileLayer, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = tileLayer.wms(props.baseUrl, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);
      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
    });
  },
  render() {
    return null;
  },
};

const render$j = () => {};


script$g.render = render$j;
script$g.__file = "src/components/LWmsTileLayer.vue";

const props$l = {
  ...props,
};

const setup$k = (props, leafletRef) => {
  const { options: layerOptions, methods: layerMethods } = setup(
    props,
    leafletRef
  );

  const options = {
    ...layerOptions,
  };

  const methods = {
    ...layerMethods,
    addLayer(layer) {
      leafletRef.value.addLayer(layer.leafletObject);
    },
    removeLayer(layer) {
      leafletRef.value.removeLayer(layer.leafletObject);
    },
  };

  vue.provide("addLayer", methods.addLayer);
  vue.provide("removeLayer", methods.removeLayer);

  return { options, methods };
};

var script$h = {
  props: props$l,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const { methods } = setup$k(props, leafletRef);

    vue.onMounted(async () => {
      const { layerGroup, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });
      leafletRef.value = layerGroup();

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);
      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });
    return render(ready, context);
  },
};

const render$k = () => {};


script$h.render = render$k;
script$h.__file = "src/components/LLayerGroup.vue";

const props$m = {
  ...props$l,
  geojson: {
    type: [Object, Array],
    default: () => ({}),
  },
};

const setup$l = (props, leafletRef) => {
  const { options: layerOptions, methods: layerGroupMethods } = setup$k(
    props,
    leafletRef
  );

  const options = {
    ...layerOptions,
    ...props,
  };

  const methods = {
    ...layerGroupMethods,
    setGeojson(newVal) {
      leafletRef.value.clearLayers();
      leafletRef.value.addData(newVal);
    },
    getGeoJSONData() {
      return leafletRef.value.toGeoJSON();
    },
    getBounds() {
      return leafletRef.value.getBounds();
    },
  };

  return { options, methods };
};

var script$i = {
  props: props$m,
  setup(props, context) {
    const leafletRef = vue.ref({});
    const ready = vue.ref(false);

    const addLayer = vue.inject("addLayer");

    const { methods, options } = setup$l(props, leafletRef);

    vue.onMounted(async () => {
      const { geoJSON, DomEvent, setOptions } = await Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require(
        'leaflet/dist/leaflet-src.esm'
      )); });

      leafletRef.value = geoJSON(props.geojson, options);

      const listeners = remapEvents(context.attrs);
      DomEvent.on(leafletRef.value, listeners);

      propsBinder(methods, leafletRef.value, props, setOptions);
      addLayer({
        ...props,
        ...methods,
        leafletObject: leafletRef.value,
      });
      ready.value = true;
    });
    return render(ready, context);
  },
};

const render$l = () => {};


script$i.render = render$l;
script$i.__file = "src/components/LGeoJson.vue";

exports.LCircle = script;
exports.LCircleMarker = script$1;
exports.LControl = script$6;
exports.LControlAttribution = script$2;
exports.LControlLayers = script$3;
exports.LControlScale = script$4;
exports.LControlZoom = script$5;
exports.LGeoJson = script$i;
exports.LIcon = script$a;
exports.LLayerGroup = script$h;
exports.LMap = script$7;
exports.LMarker = script$8;
exports.LPolygon = script$e;
exports.LPolyline = script$b;
exports.LPopup = script$d;
exports.LRectangle = script$f;
exports.LTileLayer = script$9;
exports.LTooltip = script$c;
exports.LWmsTileLayer = script$g;
//# sourceMappingURL=vue-leaflet.cjs.js.map
